Changelog
=========

0.1.0 (2018-09-06)
------------------

- Adds support for Google Container Registry.
  [href]

- Implements cache purging.
  [href]

- Shows an error if no protocol is given.
  [href]

- Changes the cache path to `~/.cache/seantis/ostree` for non-root users.
  [href]

0.0.0 (2018-08-24)
------------------

- Initial Release.
  [href]
